using System.Collections.ObjectModel;
using System.Linq;
using Telerik.XamarinForms.Common;
using Xamarin.Forms;

namespace JoshuaDemo.Portable
{
    public partial class MainPage : ContentPage
    {
        public MainPage()
        {
            InitializeComponent();
            BindingContext = new MainViewModel();
        }
    }

public class MainViewModel : NotifyPropertyChangedBase
{
    private Item selectedItem;

    public MainViewModel()
    {
        Items = new ObservableCollection<Item>(Enumerable.Range(1, 20).Select(i => new Item
        {
            Name = $"Item {i}"
        }));

        SelectedItem = Items.FirstOrDefault();
    }

    public ObservableCollection<Item> Items { get; set; }

    public Item SelectedItem
    {
        get => selectedItem;
        set
        {
            UpdateValue(ref selectedItem, value);
            ToggleIsSelected();
        }
    }

    private void ToggleIsSelected()
    {
        foreach (var item in Items)
        {
            item.IsSelected = item != SelectedItem;
        }
    }
}

    public class Item : NotifyPropertyChangedBase
    {
        private bool isSelected;
        public string Name { get; set; }

        public bool IsSelected
        {
            get => isSelected;
            set => UpdateValue(ref isSelected, value);
        }
    }

    // Placeholder the external signature pad with a button
    public class SignaturePadView : Button
    {
        public SignaturePadView()
        {
            Text = "I'm a SignaturePad";
            BorderWidth = 2;
            SignatureLineColor = Color.Transparent;
        }

        public static readonly BindableProperty SignatureLineColorProperty = BindableProperty.Create(
            "SignatureLineColor", 
            typeof(Color), 
            typeof(SignaturePadView),
            Color.Transparent, 
            propertyChanged: OnEventNameChanged);

        static void OnEventNameChanged(BindableObject bindable, object oldValue, object newValue)
        {
            if (bindable is SignaturePadView self)
            {
                self.BorderColor = (Color) newValue;
            }
        }

        public Color SignatureLineColor
        {
            get => (Color)GetValue(SignatureLineColorProperty);
            set => SetValue(SignatureLineColorProperty, value);
        }
    }
}
